==> hlint-3.5-2-x86_64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hlint
version:              3.5
visibility:           public
id:                   hlint-3.5-3VhIlrhDkmy86m3dEi26UH
key:                  hlint-3.5-3VhIlrhDkmy86m3dEi26UH
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  549e0289192cff95b10a1ff7b8393f39
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Hint.NumLiteral Test.All Test.Annotations
    Test.InputOutput Test.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hlint-3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hlint-3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hlint-3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.5-3VhIlrhDkmy86m3dEi26UH
depends:
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc base-4.17.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deriving-aeson-0.2.10-LeeLOTd2diuD8sF4A6Tjb1 directory-1.3.7.1
    extra-1.7.16-5U9Z4JlXvjsGJBQPJ1GjLc
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    filepattern-0.1.3-kZh2R3WrlCFAunQZhhV5A ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-lib-parser-ex-9.4.0.0-7heVM2EFHec96jFrLrf1Pn
    hscolour-1.25-61St7PjQxrJB3Zc5RdCary process-1.6.18.0
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-7MsEh77TKVy6A0zZ7jpp6V
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD
    yaml-0.11.11.2-4qRa9tGxPq4CL7IrSLcz39

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-3.5-3-x86_64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hlint
version:              3.5
visibility:           public
id:                   hlint-3.5-8xjMYVfKaF21Td2cQVOetx
key:                  hlint-3.5-8xjMYVfKaF21Td2cQVOetx
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  31881058376598d11f217e7803a16cc0
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Hint.NumLiteral Test.All Test.Annotations
    Test.InputOutput Test.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hlint-3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hlint-3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hlint-3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.5-8xjMYVfKaF21Td2cQVOetx
depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc base-4.17.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deriving-aeson-0.2.10-DiLFCctW7x2GdbTEL4eEYL directory-1.3.7.1
    extra-1.7.16-Bey2vPU3D4iIpeD8oPKkuc
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    filepattern-0.1.3-FLOiPYJpPf4LdviuwVOBcB ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-lib-parser-ex-9.4.0.0-DqHPYP5THeYBGBgFmIXnGQ
    hscolour-1.25-61St7PjQxrJB3Zc5RdCary process-1.6.18.0
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-7MsEh77TKVy6A0zZ7jpp6V
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD
    yaml-0.11.11.2-FQGR7qmzYmVGeoVQVKTN0

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
